@@ -13,7 +13,7 @@ from Cheese.fileHeaders import FileHeaders
 
 class CheeseController:
     """
-    ```CheeseController``` is static class for controlling endpoints. 
+    `CheeseController` is static class for controlling endpoints. 
 
     Controller documentation:
     https://kubaboi.github.io/CheeseFramework/#71-api-controllers
@@ -24,7 +24,7 @@ class CheeseController:
         """
         return client's address
 
-        ```server``` is instance of http handler
+        `server` is instance of http handler
         """
         return server.client_address[0]
 
@@ -33,7 +33,7 @@ class CheeseController:
         """
         return requests headers
         
-        ```server``` is instance of http handler
+        `server` is instance of http handler
         """
         return server.headers._headers
 
@@ -42,7 +42,7 @@ class CheeseController:
         """
         return request headers as dict
 
-        ```server``` is instance of http handler
+        `server` is instance of http handler
         """
         headers = {}
         for header in server.headers._headers:
@@ -54,7 +54,7 @@ class CheeseController:
         """
         return json array from list of modules
 
-        ```modules``` is list of CheeseModel instances
+        `modules` is list of CheeseModel instances
         """        
         jsonArray = []
         for m in modules:
@@ -66,7 +66,7 @@ class CheeseController:
         """
         return now time and add argument in seconds
 
-        ```addTime``` is time in ```seconds``` which will be added to now time. It can be negative value.
+        `addTime` is time in `seconds` which will be added to now time. It can be negative value.
         """
         return int(time.time()) + addTime
 
@@ -75,9 +75,9 @@ class CheeseController:
         """
         return true if all keys are in dictionary
 
-        ```keys``` is list of keys that should be in ```dict```
+        `keys` is list of keys that should be in `dict`
 
-        ```dict``` is tested dictionary
+        `dict` is tested dictionary
         """
         for key in keys:
             if (key not in dict):
@@ -89,9 +89,9 @@ class CheeseController:
         """
         raise BadRequest exception if any key is missing in json
 
-        ```keys``` is list of keys that should be in ```dict```
+        `keys` is list of keys that should be in `dict`
 
-        ```dict``` is tested dictionary
+        `dict` is tested dictionary
         """
         if (CheeseController.validateJson(keys, dict)): return
         raise BadRequest("Wrong json structure")
@@ -101,9 +101,9 @@ class CheeseController:
         """
         return path without arguments
 
-        ```url``` is url of request
+        `url` is url of request
 
-        splits url by ```?``` and return first part
+        splits url by `?` and return first part
 
         example:
         ```
@@ -117,9 +117,9 @@ class CheeseController:
         """
         return list of endpoints
 
-        ```url``` is url of request
+        `url` is url of request
 
-        splits url by ```/``` and returns this list
+        splits url by `/` and returns this list
 
         example:
         ```
@@ -134,9 +134,9 @@ class CheeseController:
         """
         return arguments from rest request url
 
-        ```url``` is url of request
+        `url` is url of request
 
-        ```decode``` if true than decode URL-encoded format
+        `decode` if true than decode URL-encoded format
         """
         arguments = {}
 
@@ -159,7 +159,7 @@ class CheeseController:
         """
         return bytes from post body
 
-        ```server``` is instance of http handler
+        `server` is instance of http handler
         """
         try:
             content_len = int(server.headers.get('Content-Length'))
@@ -173,7 +173,7 @@ class CheeseController:
         """
         return arguments from body of request as dictionary
 
-        ```server``` is instance of http handler
+        `server` is instance of http handler
         """
         try:
             content_len = int(server.headers.get('Content-Length'))
@@ -187,7 +187,7 @@ class CheeseController:
         """
         return cookies as dictionary from request header
 
-        ```server``` is instance of http handler 
+        `server` is instance of http handler 
         """
         cookieRaw = ""
         for header in server.headers._headers:
@@ -224,13 +224,13 @@ class CheeseController:
     @staticmethod
     def serveFile(server, file, header="text/html") -> None:
         """
-        sends file located in ```/web``` directory
+        sends file located in `/web` directory
 
-        ```server``` is instance of http handler
+        `server` is instance of http handler
 
-        ```file``` is string path to any file located in ```/web``` directory
+        `file` is string path to any file located in `/web` directory
 
-        ```header``` is string of header for http response 
+        `header` is string of header for http response 
         """
         file = unquote(file)
         file = ResMan.joinPath(ResMan.web(), file)
@@ -270,12 +270,12 @@ class CheeseController:
         """
         create response as tuple
         
-        ```dict``` is response dictionary. Dictionary will be dumped by ```json``` library 
-        and coded into bytes with ```utf-8``` coding. 
+        `dict` is response dictionary. Dictionary will be dumped by `json` library 
+        and coded into bytes with `utf-8` coding. 
 
-        ```code``` is http status code as ```int```
+        `code` is http status code as `int`
 
-        ```headers``` is dict with headers and its values
+        `headers` is dict with headers and its values
         """
 
         if ("Content-type" not in headers.keys()):
@@ -288,9 +288,9 @@ class CheeseController:
         """
         send response to client
 
-        ```server``` is instance of http handler
+        `server` is instance of http handler
 
-        ```response``` is tuple (response object created in ```CheeseController.createResponse(...)``` method)
+        `response` is tuple (response object created in `CheeseController.createResponse(...)` method)
         """
         server.send_response(response[1])
         for headerKey in response[2].keys():
