@@ -7,12 +7,14 @@ import re
 from Cheese.metadata import Metadata
 from Cheese.cheeseModel import CheeseModel
 from Cheese.resourceManager import ResMan
-from Cheese.database import Database
+from Cheese.appSettings import Settings
+if (Settings.allowDB):
+    from Cheese.database import Database
 from Cheese.Logger import Logger
 
 class CheeseRepository:
     """
-    ```CheeseRepository``` is static class for communication with database
+    `CheeseRepository` is static class for communication with database
     """
 
     testing = False
@@ -22,7 +24,7 @@ class CheeseRepository:
     @classmethod
     def model(cls, addId=0) -> CheeseModel:
         """
-        return ```CheeseModel``` with ```Primary key```, ```modelName``` and ```scheme```
+        return `CheeseModel` with `Primary key`, `modelName` and `scheme`
         """
         repository = Metadata.getRepositoryFromClass(cls.__name__) 
         modelName = Metadata.getModel(repository)
@@ -46,25 +48,27 @@ class CheeseRepository:
     @classmethod
     def findAll(cls) -> list:
         """
-        return whole table of database as list of ```CheeseModel```
+        return whole table of database as list of `CheeseModel`
         """
         return CheeseRepository.query(cls.__name__)
 
     @classmethod
     def find(cls, primaryKey) -> CheeseModel:
         """
-        return one ```CheeseModel``` by ```Primary key```
+        return one `CheeseModel` by `Primary key`
         """
         return CheeseRepository.query(cls.__name__, primaryKey=primaryKey)
 
     @classmethod
     def findBy(cls, columnName, value) -> list:
         """
-        return list of ```CheeseModel```
+        `DEPRECATED`
 
-        ```columnName``` name of column for filtering
+        return list of `CheeseModel`
 
-        ```value``` value of ```column```
+        `columnName` name of column for filtering
+
+        `value` value of `column`
 
         example:
         ```
@@ -74,16 +78,19 @@ class CheeseRepository:
         SQL: "... WHERE age = 15 ..."
         ```
         """
+        Logger.warning(f"{Logger.FAIL}!DEPRECATION!{Logger.WARNING} Method findBy(...) is deprecated since 1.6. Use findByColumns(...) instead")
         return CheeseRepository.query(cls.__name__, columnName="columnName-" + columnName, value=value)
 
     @classmethod
     def findOneBy(cls, columnName, value) -> CheeseModel:
         """
-        return one ```CheeseModel``` by ```columnName```
+        `DEPRECATED`
 
-        ```columnName``` name of column for filtering
+        return one `CheeseModel` by `columnName`
 
-        ```value``` value of ```column```
+        `columnName` name of column for filtering
+
+        `value` value of `column`
 
         example:
         ```
@@ -93,12 +100,55 @@ class CheeseRepository:
         SQL: "... WHERE age = 15 ..."
         ```
         """
+        Logger.warning(f"{Logger.FAIL}!DEPRECATION!{Logger.WARNING} Method findOneBy(...) is deprecated since 1.6. Use findOneByColumns(...) instead")
         return CheeseRepository.query(cls.__name__, columnName="columnName-" + columnName, value=value)
 
+    @classmethod
+    def findByColumns(cls, **kwargs) -> list:
+        """
+        return list of `CheeseModel`
+
+        `kwargs` is dictionary of column names and its values
+
+        example:
+        ```
+        findByColumns(age=15, gender="m")
+        ->
+        SQL: "... WHERE age = 15 AND gender = 'm' ..."
+        ```
+        """
+        filter = ""
+        for i, column in enumerate(kwargs.keys()):
+            filter += f"{column}={CheeseRepository.getTypeOf(kwargs[column])}"
+            if (i < len(kwargs.keys())-1):
+                filter += " AND "
+        return CheeseRepository.query(cls.__name__, filter="columnName-" + filter)
+
+    @classmethod
+    def findOneByColumns(cls, **kwargs) -> CheeseModel:
+        """
+        return one `CheeseModel`
+
+        `kwargs` is dictionary of column names and its values
+
+        example:
+        ```
+        findOneByColumns(age=15, gender="m")
+        ->
+        SQL: "... WHERE age = 15 AND gender = 'm' ..."
+        ```
+        """
+        filter = ""
+        for i, column in enumerate(kwargs.keys()):
+            filter += f"{column}={CheeseRepository.getTypeOf(kwargs[column])}"
+            if (i < len(kwargs.keys())-1):
+                filter += " AND "
+        return CheeseRepository.query(cls.__name__, filter="columnName-" + filter)
+
     @classmethod
     def findNewId(cls) -> int:
         """
-        find new available ```Primary key```
+        find new available `Primary key`
         """
         return CheeseRepository.query(cls.__name__)+1
 
@@ -107,7 +157,7 @@ class CheeseRepository:
         """
         creates new row in database
 
-        ```obj``` is ```CheeseModel``` object
+        `obj` is `CheeseModel` object
         """
         return CheeseRepository.query(cls.__name__, obj=obj)
 
@@ -116,7 +166,7 @@ class CheeseRepository:
         """
         updates row in database
 
-        ```obj``` is ```CheeseModel``` object
+        `obj` is `CheeseModel` object
         """
         return CheeseRepository.query(cls.__name__, obj=obj)
 
@@ -125,7 +175,7 @@ class CheeseRepository:
         """
         deletes row from database
 
-        ```obj``` is ```CheeseModel``` object
+        `obj` is `CheeseModel` object
         """
         return CheeseRepository.query(cls.__name__, obj=obj)
 
@@ -136,7 +186,7 @@ class CheeseRepository:
         """
         sets repository testing enviroment
 
-        ```mockManager``` is instance of ```MockManager``` used by testing
+        `mockManager` is instance of `MockManager` used by testing
         """
         CheeseRepository.mockManager = mockManager
         CheeseRepository.testing = True
@@ -153,9 +203,9 @@ class CheeseRepository:
         """
         Access point to database. Returns database output.
 
-        ```userRepository``` is string name of used repository
+        `userRepository` is string name of used repository
 
-        ```**kwargs``` is ```dict``` of arguments for SQL request
+        `**kwargs` is `dict` of arguments for SQL request
         """
         if (userRepository == ""):
             userRepository = CheeseRepository.findUserRepository()
