@@ -1,5 +1,8 @@
 #cheese
 
+from re import M
+
+
 class FileHeaders:
     """
     https://www.geeksforgeeks.org/http-headers-content-type/
@@ -13,7 +16,13 @@ class FileHeaders:
         "js": "application/javascript",
         "pdf": "application/pdf",
         "zip": "application/zip",
-        "xlsx": "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet"
+        "xlsx": "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet",
+        "mp3": "audio/mpeg",
+        "gif": "image/gif",
+        "png": "image/png",
+        "jpeg": "image/jpeg",
+        "mp4": "video/mp4",
+        "mpeg": "video/mpeg"
     }
 
     @staticmethod
