@@ -1,13 +1,15 @@
 #cheese
 
+import json
+
 from Cheese.mockManager import MockManager
 
 class Mock:
 
-    def __init__(self, repositoryName):
+    def __init__(self, repository):
         self.whenReturns = {}
         self.catch = {}
-        self.repoName = repositoryName
+        self.repoName = repository.className()
         MockManager.setMock(self)
 
     def whenReturn(self, methodName, response, **kwargs):
@@ -43,6 +45,25 @@ class Mock:
 class ServerMock:
 
     def __init__(self, **kwargs):
-
+        self.headers = HeadersMock()
         for key in kwargs.keys():
-            setattr(self, key, kwargs[key])
\ No newline at end of file
+            setattr(self, key, kwargs[key])
+
+    def mockPostBody(self, jsn):
+        self.rfile = RfileMock(jsn)
+
+class HeadersMock:
+
+    def __init__(self, **kwargs):
+        self.attrs = kwargs
+
+    def get(self, smth):
+        return 0
+
+class RfileMock:
+
+    def __init__(self, jsn):
+        self.content = json.dumps(jsn).encode("utf-8")
+
+    def read(self, lngth):
+        return self.content
\ No newline at end of file
